.. _trojanvision.datasets.normal:

normal
=======
.. currentmodule:: trojanvision.datasets

.. autoclass:: MNIST
   :members:

.. autoclass:: CIFAR10
   :members:

.. autoclass:: CIFAR100
   :members:

.. autoclass:: ImageNet16
   :members:

.. autoclass:: ImageNet32
   :members:

.. autoclass:: STL10
   :members:
